@@ -6,9 +6,9 @@ use Exporter ();
 use Carp qw(croak);
 use vars qw($VERSION @ISA @EXPORT);
 
-$VERSION = "0.05";
+$VERSION = "0.06";
 @ISA = qw(Exporter);
-@EXPORT = qw(indexf);
+@EXPORT = qw(indexf rindexf);
 
 sub indexf {
   my $filehandle=shift;
